@@ -86,7 +86,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -217,6 +217,18 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_92(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KCOREADDONS_DEPRECATED_VERSION_5_95(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_95(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCOREADDONS_DEPRECATED_VERSION_5_97(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -283,7 +295,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -293,7 +305,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -414,6 +426,18 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_92(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KCOREADDONS_DEPRECATED_VERSION_5_95(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_95(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCOREADDONS_DEPRECATED_VERSION_5_97(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
